from setuptools import setup

setup(
    name='crawlab-ai',
    version='0.0.3',
    packages=['crawlab_ai'],
    url='https://github.com/crawlab-team/crawlab-ai-sdk',
    license='MIT',
    author='Marvin Zhang',
    author_email='tikazyq@163.com',
    description='SDK for Crawlab AI',
    package_dir={'crawlab_ai': 'crawlab_ai'},
    keywords=['crawlab', 'ai'],
)
